==> helpers-v0.2.1.tar.bz2: helpers-v0.2.1/src/convert.php <==
<?php

use Illuminate\Support\HtmlString;
use Illuminate\Support\Collection;
use Illuminate\Support\Str;

if ( !function_exists('carbonize')) {
    /**
     * Converti recursivement les dates fr en Instance Carbon dans une collection
     * @param  Mixed  $collection   Données à traitées
     * @return Mixed            Les données après traitement
     */
    function carbonize($collection)
    {
        if ($collection instanceof Collection) {
            $collection = $collection->map(function($item, $key) {
                return carbonize($item);
            });
        } else if (is_object($collection)) {
            $datas_array = get_object_vars($collection);
            foreach ($datas_array as $key => $value) {
                $collection->{$key} = carbonize($value);
            }

        } else if (is_array($collection)) {
            foreach ($collection as $key => $value) {
               $collection[$key] = carbonize($value);
            }
        } else {
            // Detection d'une date selon le format
            if (preg_match("/^[0-9]{1,2}\/[0-9]{1,2}\/[0-9]{4}$/", $collection)) {
                $collection = \Carbon\Carbon::createFromFormat('d/m/Y', $collection)->startOfDay();
            } else if (preg_match("/^[0-9]{1,2}\/[0-9]{1,2}\/[0-9]{2}$/", $collection)) {
                $collection = \Carbon\Carbon::createFromFormat('d/m/y', $collection)->startOfDay();
            }
        }

        return $collection;
    }
}

if ( !function_exists('collectize')) {
    /**
     * Converti les tableaux d'une collection en Instance de Collection
     * @param  Mixed  $collection   Données à traitées
     * @return Mixed            Les données après traitement
     */
    function collectize($collection)
    {
        if ($collection instanceof Collection) {
            $collection = $collection->map(function($item, $key) {
                return collectize($item);
            });
        } else if (is_object($collection)) {
            $datas_array = get_object_vars($collection);
            foreach ($datas_array as $key => $value) {
                $collection->{$key} = collectize($value);
            }

        } else if (is_array($collection)) {

            foreach ($collection as $key => $value) {
               $collection[$key] = collectize($value);
            }

            $collection = collect($collection);
        }

        return $collection;
    }
}

if ( !function_exists('objectize')) {
    /**
     * Converti les tableaux associatif d'une collection en stdObject
     * @param  Mixed  $collection   Données à traitées
     * @return Mixed            Les données après traitement
     */
    function objectize($collection)
    {
        if ($collection instanceof Collection) {

            $collection = $collection->map(function($item, $key) {
                return objectize($item);
            });

        } else if (is_object($collection)) {

            $datas_array = get_object_vars($collection);
            foreach ($datas_array as $key => $value) {
                $collection->{$key} = objectize($value);
            }

        } else if (is_array($collection)) {

            // Détection d'un tableau associatif
            if(count($collection) != 0 && array_keys($collection) !== range(0, count($collection) - 1)) {

                $sub_data = new \StdClass;
                foreach ($collection as $key => $value) {
                    if (is_array($value)) {
                        $sub_data->{$key} = objectize($value);
                    } else {
                        $sub_data->{$key} = $value;
                    }
                }
                $collection = $sub_data;

            } else {

                foreach ($collection as $key => $value) {
                   $collection[$key] = objectize($value);
                }
            }

        }

        return $collection;
    }
}

if ( !function_exists('csv_to_collection')) {
    /**
     * Retourne une collection d'object standard à partir d'une chaine de caractère de type csv
     * @param  string $csv                  Le contenu du CSV
     * @param  string $delimiter            Le séparateur du CSV
     * @param  string $without_column_name  Si la 1ère ligne ne correspond pas aux entêtes de colonnes
     * @return Collection                   La collection
     */
    function csv_to_collection(string $csv, string $delimiter = ';', $without_column_name = false)
    {
        $datas   = array();
        $collect = collect();
        $headers = [];

        // Récupération des lignes (en prenant en compte les retours à la ligne dans les contenus)
        preg_match_all('/[^"\n]*("[^"]*\n*")?.*/', $csv, $matches);

        $lines = array_filter($matches[0]);

        // Parsage du CSV
        foreach ($lines as $line => $value) {
            if (!$without_column_name && $line == 0) {
                $headers = str_getcsv($value, $delimiter);
            } else {
                $values = str_getcsv($value, $delimiter);
                if (count($values) > 1) {
                    $datas[] = $values;
                }
            }
        }

        // Si la première ligne du csv correspond aux entêtes de colonnes
        if (!$without_column_name) {
            // Création de la collection
            foreach ($datas as $line => $data) {

                $obj_line = new stdClass;
                foreach ($headers as $col => $name) {
                    if (isset($data[$col])) {
                        $col_name = str_replace('-', '_', Str::slug($name));
                        $value = trim(trim($data[$col], '"'));
                        $obj_line->{$col_name} = $value;
                    }
                }

                $collect->push($obj_line);
            }
        } else {
            $collect = collect($datas);
        }

        return $collect;
    }
}

if ( !function_exists('array_to_string')) {
    /**
     * Converti un tableau en string
     * @param  array  $array Le tableau à convertir
     * @return string        La chaine de caractères résultante
     */
    function array_to_string(array $array)
    {
        $template = '[%s]';

        $items = '';

        if (count($array)) {
            $items = "'" . implode("', '", $array) . "'";
        }

        return sprintf($template, $items);
    }
}

if ( !function_exists('string_to_float')) {
    /**
     * Parsage d'une chaine de caractère en nombre flottant
     * @param  String $value Valeur à virgule
     * @return Float         Nombre flottant
     */
    function string_to_float($value)
    {
        if (!is_null($value)) {
            $string = str_replace(' ', '', $value);
            $string = str_replace(',', '.', $string);
            return floatval($string);
        } else {
            return 0;
        }
    }
}

==> helpers-v1.0.3.tar.bz2: helpers-v1.0.3/src/convert.php <==
<?php

use Illuminate\Support\HtmlString;
use Illuminate\Support\Collection;
use Illuminate\Support\Str;

if ( !function_exists('carbonize')) {
    /**
     * Converti recursivement les dates fr en Instance Carbon dans une collection
     * @param  Mixed  $collection   Données à traitées
     * @return Mixed            Les données après traitement
     */
    function carbonize($collection)
    {
        if ($collection instanceof Collection) {
            $collection = $collection->map(function($item, $key) {
                return carbonize($item);
            });
        } else if (is_object($collection)) {
            $datas_array = get_object_vars($collection);
            foreach ($datas_array as $key => $value) {
                $collection->{$key} = carbonize($value);
            }

        } else if (is_array($collection)) {
            foreach ($collection as $key => $value) {
               $collection[$key] = carbonize($value);
            }
        } else {
            // Detection d'une date selon le format
            if (preg_match("/^[0-9]{1,2}\/[0-9]{1,2}\/[0-9]{4}$/", $collection)) {
                $collection = \Carbon\Carbon::createFromFormat('d/m/Y', $collection)->startOfDay();
            } else if (preg_match("/^[0-9]{1,2}\/[0-9]{1,2}\/[0-9]{2}$/", $collection)) {
                $collection = \Carbon\Carbon::createFromFormat('d/m/y', $collection)->startOfDay();
            }
        }

        return $collection;
    }
}

if ( !function_exists('collectize')) {
    /**
     * Converti les tableaux d'une collection en Instance de Collection
     * @param  Mixed  $collection   Données à traitées
     * @return Mixed            Les données après traitement
     */
    function collectize($collection)
    {
        if ($collection instanceof Collection) {
            $collection = $collection->map(function($item, $key) {
                return collectize($item);
            });
        } else if (is_object($collection)) {
            $datas_array = get_object_vars($collection);
            foreach ($datas_array as $key => $value) {
                $collection->{$key} = collectize($value);
            }

        } else if (is_array($collection)) {

            foreach ($collection as $key => $value) {
               $collection[$key] = collectize($value);
            }

            $collection = collect($collection);
        }

        return $collection;
    }
}

if ( !function_exists('objectize')) {
    /**
     * Converti les tableaux associatif d'une collection en stdObject
     * @param  Mixed  $collection   Données à traitées
     * @return Mixed            Les données après traitement
     */
    function objectize($collection)
    {
        if ($collection instanceof Collection) {

            $collection = $collection->map(function($item, $key) {
                return objectize($item);
            });

        } else if (is_object($collection)) {

            $datas_array = get_object_vars($collection);
            foreach ($datas_array as $key => $value) {
                $collection->{$key} = objectize($value);
            }

        } else if (is_array($collection)) {

            // Détection d'un tableau associatif
            if(count($collection) != 0 && array_keys($collection) !== range(0, count($collection) - 1)) {

                $sub_data = new \StdClass;
                foreach ($collection as $key => $value) {
                    if (is_array($value)) {
                        $sub_data->{$key} = objectize($value);
                    } else {
                        $sub_data->{$key} = $value;
                    }
                }
                $collection = $sub_data;

            } else {

                foreach ($collection as $key => $value) {
                   $collection[$key] = objectize($value);
                }
            }

        }

        return $collection;
    }
}

if ( !function_exists('csv_to_collection')) {
    /**
     * Retourne une collection d'object standard à partir d'une chaine de caractère de type csv
     * @param  string $csv                  Le contenu du CSV
     * @param  string $delimiter            Le séparateur du CSV
     * @param  string $without_column_name  Si la 1ère ligne ne correspond pas aux entêtes de colonnes
     * @return Collection                   La collection
     */
    function csv_to_collection(string $csv, string $delimiter = ';', $without_column_name = false)
    {
        $datas   = array();
        $collect = collect();
        $headers = [];

        // Récupération des lignes (en prenant en compte les retours à la ligne dans les contenus)
        preg_match_all('/[^"\n]*("[^"]*\n*")?.*/', $csv, $matches);

        $lines = array_filter($matches[0]);

        // Parsage du CSV
        foreach ($lines as $line => $value) {
            if (!$without_column_name && $line == 0) {
                $headers = str_getcsv($value, $delimiter);
            } else {
                $values = str_getcsv($value, $delimiter);
                if (count($values) > 1) {
                    $datas[] = $values;
                }
            }
        }

        // Si la première ligne du csv correspond aux entêtes de colonnes
        if (!$without_column_name) {
            // Création de la collection
            foreach ($datas as $line => $data) {

                $obj_line = new stdClass;
                foreach ($headers as $col => $name) {
                    if (isset($data[$col])) {
                        $col_name = str_replace('-', '_', Str::slug($name));
                        $value = trim(trim($data[$col], '"'));
                        $obj_line->{$col_name} = $value;
                    }
                }

                $collect->push($obj_line);
            }
        } else {
            $collect = collect($datas);
        }

        return $collect;
    }
}

if ( !function_exists('array_to_string')) {
    /**
     * Converti un tableau en string
     * @param  array  $array Le tableau à convertir
     * @return string        La chaine de caractères résultante
     */
    function array_to_string(array $array): string
    {
        $template = '[%s]';
        $string = '';

        // Si tableau indexé simple
        if (is_indexed_array($array)) {

            $string = '"' . implode('", "', $array) . '"';

        } else {

            $values = [];
            // Traitement d'un tableau associatif
            foreach($array as $key => $item) {

                $value = '';
                if (is_array($item)) {
                    $value = array_to_string($item);
                } else if (is_string($item)) {
                    $value = '"' . $item . '"';
                } else if (is_bool($item)) {
                    $value = $item ? 'true' : 'false';
                } else {
                    $value = $item;
                }

                $values[] = vsprintf('"%s" => %s', [$key, $value]);
            }

            $string = implode(', ', $values);
        }

        return sprintf($template, $string);
    }
}

if ( !function_exists('string_to_float')) {
    /**
     * Parsage d'une chaine de caractère en nombre flottant
     * @param  String $value Valeur à virgule
     * @return Float         Nombre flottant
     */
    function string_to_float($value)
    {
        if (!is_null($value)) {
            $string = str_replace(' ', '', $value);
            $string = str_replace(',', '.', $string);
            return floatval($string);
        } else {
            return 0;
        }
    }
}

if ( !function_exists('float_to_money')) {
    /**
     * Parsage d'une flottant en nombre monétaire €
     * @param  Float $value Valeur à virgule
     * @return String         "1 234,56 €"
     */
    function float_to_money($value)
    {
        return number_format($value, 2, ',', ' ') . ' €';
    }
}
